import { EventEmitter } from '.';
interface StateSubscription<StateMap> {
    readonly on: EventEmitter<StateMap>['on'];
    readonly off: EventEmitter<StateMap>['off'];
    readonly addListener: EventEmitter<StateMap>['addListener'];
    readonly removeListener: EventEmitter<StateMap>['removeListener'];
}
export declare type State<T> = T & StateSubscription<T>;
export declare class StateManager<StateMapT extends Record<string, any>> extends EventEmitter<StateMapT> {
    #private;
    readonly globalName: string;
    constructor(globalName: string, initialState: StateMapT, persistent?: boolean);
    has(key: string): boolean;
    get<Key extends keyof StateMapT>(key: Key): StateMapT[Key];
    set<Key extends keyof StateMapT>(key: Key, value: StateMapT[Key]): void;
    replaceState(state: StateMapT): void;
    clearPersistentState(): void;
}
/** Read-only wrapper of the StateManager */
export declare class StateClient<StateMapT extends Record<string, any>> {
    #private;
    readonly globalName: string;
    constructor(globalName: string);
    /**
     * Add a listener to an event
     * @param eventName Event name
     * @param listener Listener function
     * @param ref Reference value that can be used to remove this listener,
     * if omitted it will be the listener itself
     */
    addListener(...args: Parameters<StateManager<StateMapT>['addListener']>): void;
    /**
     * Add multiple listeners for events
     * @param listenersBundle Map of events to listeners
     * @param ref Reference value that can be used to remove the listeners
     */
    on(...args: Parameters<StateManager<StateMapT>['on']>): void;
    /**
     * Remove multiple listeners for events
     * @param eventNames Array of event names
     * @param ref Reference value that map to listeners
     */
    off(...args: Parameters<StateManager<StateMapT>['off']>): void;
    /**
     * Remove a listener to an event
     * @param eventName Event name
     * @param ref Reference value that was used when adding the listener,
     * this can be the listener itself
     */
    removeListener(...args: Parameters<StateManager<StateMapT>['removeListener']>): void;
    has(key: string): boolean;
    get<Key extends keyof StateMapT>(key: Key): StateMapT[Key];
}
export declare function makeNiceState<StateMapT extends Record<string, any>>(manager: StateManager<StateMapT>): State<StateMapT>;
export declare function makeNiceStateClient<StateMapT extends Record<string, any>>(globalName: string): State<StateMapT>;
export {};
//# sourceMappingURL=state.d.ts.map